getttestDominantRADJ is a support function for inferring a dominant-distribution network using Student's t-test.
getttestDominantRADJ(Values, Group, GroupList, alpha)This function returns an adjacency matrix of a dominant-distribution network adjMat
and the corresponding p-values of all category pairs.
An element of adjacency matrix: one if GroupList[j] category dominates GroupList[i] using Student's t-test, otherwise zero.
A p-value of Student's t-test for adjMat[i,j].
is a vector of real-number values
is a vector of categories of each real number in Values
is a list of names of categories ascendingly ordered by their means.
is a significance level using in both confidence intervals and ordering inference it has the range [0,1].