Learn R Programming

EDOIF (version 0.1.3)

print.EDOIF: print.EDOIF function

Description

print.EDOIF is a support function for printing results of ordering inference in text.

Usage

# S3 method for EDOIF
print(x, ...)

Arguments

x

is an object of EDOIF class that contains the results of ordering inference.

...

Signature for S3 generic function.

Examples

Run this code
# Generate simulation data with 100 samples per categories

simData<-SimNonNormalDist(nInv=100)

# Performing ordering infernce from simData

resultObj<-EDOIF(simData$Values,simData$Group)

# Print results in text mode

print(resultObj)


Run the code above in your browser using DataLab